﻿/*****************************************************
SWFExpire ActionScript 2.0 Component
Version: 1.1, 12/15/2006 - 6/29/2007
Author(s): Damian Taggart, Mindshare Studios, Inc.
Purpose: Causes the SWF to "expire" with a custom
message set at author-time if the expiration date
has passed.
*****************************************************/

[IconFile("SWFExpire.png")]

class net.mindsharemedia.security.SWFExpire extends MovieClip {
	
	static var symbolName:String = "SWFExpire";
	static var symbolOwner:SWFExpire = SWFExpire;
	static var className:String = "SWFExpire";
	
	// variable declarations	
	private var _boundingBox:MovieClip;
	private var expirationDate:Date;
	
	[Inspectable(defaultValue=false,name="Use MovieClip", type=Boolean)]
	private var useMovieClip:Boolean;

	[Inspectable(name="MovieClip Identifier", type=String)]
	private var clipID:String;
	
	[Inspectable(defaultValue="January",enumeration="January,February,March,April,May,June,July,August,September,October,November,December", name="Expiration Month",type=String)]
	private var expirationMonth:Number;
	
	[Inspectable(defaultValue="1",name="Expiration Day",type=Number)]
	private var expirationDay:Number;
	
	[Inspectable(defaultValue="2007",name="Expiration Year",type=Number)]
	private var expirationYear:Number;
	
	[Inspectable(defaultValue="This content has expired! Please visit mysite.com for more info.",name="Message Text",type=String)]
	private var messageText:String;
	
	[Inspectable(defaultValue="sans",enumeration="sans,serif",name="Font Face",type=String)]
	private var fontFace:String;
	
	[Inspectable(defaultValue="#FFFFFF",name="Font Color",type=Color)]
	private var txtColor:Number;
	
	[Inspectable(defaultValue="#000000",name="Background Color",type=Color)]
	private var bgColor:Number;
	
	// constructor
	private function SWFExpire() {
		if (!_global.isLivePreview && this._name != "obj") {
			init();
		}
	}
	
	private function init():Void {
		check();
	}
	
	public function check():Void {
		if (isExpired()) {
			expire();
		} else {
			trace('SWFExpire: This file will expire on '+expirationDate.toString()+'.');
		}
	}
	
	// helper functions
	private function isExpired():Boolean {
		// check if the SWf has expired
		var result:Boolean = (new Date().getTime() >= formatDate().getTime()) ? true : false;
		return result;
	}
	
	private function formatMessage():String {
		// set the default face
		fontFace == "serif" ? fontFace = "Times, Times New Roman" : fontFace = "Arial,Helvetica,sans-serif";
		messageText = "<font face='" + fontFace + "'>" + messageText + "</font>";
		return messageText;
	}

	private function formatDate():Date {
		// set the expiration date
		if(expirationYear.toString().length !== 4) {
			trace('SWFExpire [ERROR]: Please specify the expiration year in a four-digit format.\nExample: 2006');
			expirationYear = new Date().getYear();
		}
		if(expirationDay < 1 || expirationDay > 31) {
			trace('SWFExpire [ERROR]: Please specify the expiration date as a number between 1 - 31.\nExample: 24');
			expirationDay = new Date().getDate();
		}
		var expirationMonthNum:Number;
		switch (expirationMonth) {
		case "January" :
			expirationMonthNum = 0;
			break;
		case "February" :
			expirationMonthNum = 1;
			break;
		case "March" :
			expirationMonthNum = 2;
			break;
		case "April" :
			expirationMonthNum = 3;
			break;
		case "May" :
			expirationMonthNum = 4;
			break;
		case "June" :
			expirationMonthNum = 5;
			break;
		case "July" :
			expirationMonthNum = 6;
			break;
		case "August" :
			expirationMonthNum = 7;
			break;
		case "September" :
			expirationMonthNum = 8;
			break;
		case "October" :
			expirationMonthNum = 9;
			break;
		case "November" :
			expirationMonthNum = 10;
			break;
		case "December" :
			expirationMonthNum = 11;
			break;
		default :
			expirationMonthNum = 0;
			break;
		}
		expirationDate = new Date(expirationYear, expirationMonthNum, expirationDay);
		return expirationDate;
	}
	
	// actions when swf has expired
	private function expire():Void {
		
		// freeze playback
		_root.gotoAndStop(1);
		stopAllSounds();
		
		// create the expired ui
		var block:MovieClip = _root.createEmptyMovieClip("block" + new Date().valueOf(), _root.getNextHighestDepth());
		var bg:MovieClip = block.createEmptyMovieClip("bg", 1);
		bg.beginFill(bgColor);
		bg.moveTo(0, 0);
		bg.lineTo(Stage.width, 0);
		bg.lineTo(Stage.width, Stage.height);
		bg.lineTo(0, Stage.height);
		bg.lineTo(0, 0);
		bg.endFill();
		// prevent any user interaction
		bg.onPress = function() { };
		bg.useHandCursor = false;
		
		if (useMovieClip) {
			block.attachMovie(clipID, "clip", 2);
		}
		
		// display the message
		var msg_txt:TextField = block.createTextField("msg_txt", 3, 0, 0, Stage.width, Stage.height);
		msg_txt.autoSize = "left";
		msg_txt.wordWrap = true;
		msg_txt.selectable = false;
		msg_txt.multiline = true;
		msg_txt.html = true;
		msg_txt.textColor = txtColor;
		msg_txt._x = 10;
		msg_txt._y = 10;
		msg_txt.htmlText = formatMessage();
		
		// cleanup
		for (var s:String in this) {
			this[s] = undefined;
		}
		
	}
}
